# Kangeo


[![image](https://img.shields.io/pypi/v/Kangeo.svg)](https://pypi.python.org/pypi/Kangeo)
[![image](https://img.shields.io/conda/vn/conda-forge/Kangeo.svg)](https://anaconda.org/conda-forge/Kangeo)


**A geospatial python package**


-   Free software: MIT License
-   Documentation: https://geo.Kangeo.org


## Features

-   TODO
